

function [lb,ub,nVar,fobj] = TestFunction(F)


switch F
    case 'Ackley'
        fobj = @Ackley;
        lb=-32;
        ub=32;
        nVar=10;
        
    case 'Rastrigin'
        fobj = @Rastrigin;
        lb=-10;
        ub=10;
        nVar=10;
                
    case 'Alpine'
        fobj = @Alpine;
        lb=-10;
        ub=10;
        nVar=30;
  
    case 'Levy'
        fobj = @Levy;
        lb=-10;
        ub=10;
        nVar=30;
        
    case 'Griewank'
        fobj = @Griewank;
        lb=-600;
        ub=600;
        nVar=30;
        
     case 'schwefel22'
        fobj = @schwefel22;
        lb=-10;
        ub=10;
        nVar=30;
        
     case 'Michalewicz'
        fobj = @Michalewicz;
        lb=0;
        ub=pi;
        nVar=10;
        
     case 'levy_montalo'
        fobj = @levy_montalo;
        lb=-5;
        ub=5;
        nVar=10;
        
   %%%%庯
    case 'sphere'
        fobj = @sphere;
        lb=-100;
        ub=100;
        nVar=30;
        
    case 'Zakharove'
        fobj = @Zakharove;
        lb=-5;
        ub=10;
        nVar=10;
        
   case 'Rosenbrock'
        fobj = @Rosenbrock;
        lb=-5;
        ub=10;
        nVar=10;
  
     case 'dixonprice'
        fobj = @dixonprice;
        lb=-5;
        ub=10;
        nVar=30;
        
     case 'sumsquare'
        fobj = @sumsquare;
        lb=-10;
        ub=10;
        nVar=30;
        
     case 'quartic'
        fobj = @quartic;
        lb=-1.28;
        ub=1.28;
        nVar=10;
        
     case 'elliptic'
        fobj = @elliptic;
        lb=-100;
        ub=100;
        nVar=10;
        
         %%%̶Ժ
         
   case 'drop_wave'
        fobj = @drop_wave;
        lb=-5.12;
        ub=5.12;
        nVar=2;
 
   case 'schaffer'
        fobj = @schaffer;
        lb=-100;
        ub=100;
        nVar=2;
        
   case 'cross_in_tray'
        fobj = @cross_in_tray;
        lb=-10;
        ub=10;
        nVar=2;
 
 
        
end

end

% Ackley

function o = Ackley(xx)
nVar = length(xx);
sum1=0;
sum2=0;
for ii = 1:nVar
	xi = xx(ii);
    sum1=sum1+xi.^2;
    sum2=sum2+cos(2*pi.*xi);
end
o=-20*exp(-.2*sqrt(sum1/nVar))-exp(sum2/nVar)+20+exp(1);
end

% Rastrigin

function o = Rastrigin(xx)
nVar = length(xx);
sum = 0;
for ii = 1:nVar
	xi = xx(ii);
    sum=sum+(xi.^2-10*cos(2*pi.*xi));
end
o=10*nVar+sum;
end

% Alpine

function o = Alpine(xx)
nVar = length(xx);
sum = 0;
for ii = 1:nVar
	xi = xx(ii);
sum=sum+abs(xi.*sin(xi)+0.1*xi);
end
o=sum;
end

%Levy

function o = Levy(xx)

nVar = length(xx);
for ii = 1:nVar
	w(ii) = 1 + (xx(ii) - 1)/4;
end
term1 = (sin(pi*w(1)))^2;
term3 = (w(nVar)-1)^2 * (1+(sin(2*pi*w(nVar)))^2);
sum = 0;
for ii = 1:(nVar-1)
	wi = w(ii);
        new = (wi-1)^2 * (1+10*(sin(pi*wi+1))^2);
	sum = sum + new;
end

o = term1 + sum + term3;

end

%Griewank

function o = Griewank(xx)
nVar = length(xx);
sum1 = 0;
sum2=1;
for ii = 1:nVar
	xi = xx(ii);
    sum1=sum1+((xi.^2)/4000);
    sum2=sum2*cos(xi./sqrt(ii));
end
o=sum1-sum2+1;
end


%schwefel22

function o =schwefel22(xx)
nVar = length(xx);
sum1 = 0;
sum2=1;
for ii = 1:nVar
	xi = xx(ii);
    sum1=sum1+abs(xi);
    sum2=sum2*abs(xi);
end
o=sum1+sum2;
end


%Michalewicz
function o =Michalewicz(xx)
nVar = length(xx);
sum = 0;
for ii = 1:nVar
	xi = xx(ii);
	new = sin(xi) * ((sin(ii*xi^2/pi))^20);
	sum  = sum + new;
end
o= -sum;
end



%levy_montalo

function o = levy_montalo(xx)
x1=xx(1);
nVar = length(xx);
sum1 = 0.1*(sin(3*pi*x1)).^2;
sum2=0;
for ii = 1:(nVar-1)
	xi = xx(ii);
    xnext=xx(ii+1);
    sum2=sum2+((xi-1).^2).*(1+(sin(3*pi.*xnext)).^2);
end
    xd=xx(nVar);
    sum3=((xd-1).^2).*(1+(sin(2*pi.*xd)).^2);
o=sum1+sum2+sum3;
end

%%%庯

%sphere

function o = sphere(xx)
nVar = length(xx);
sum = 0;
for ii = 1:nVar
	xi = xx(ii);
    sum=sum+xi.^2;
end
o=sum;
end

% Zakharove

function o = Zakharove(xx)
nVar = length(xx);
sum1=0;
sum2=0;
sum3=0;
for ii = 1:nVar
	xi = xx(ii);
    sum1=sum1+xi.^2;
    sum2=sum2+0.5*ii.*xi;
    sum3=sum3+0.5*ii.*xi;
end
o=sum1+(sum2).^2+(sum3).^4;
end

%Rosenbrock

function o = Rosenbrock(xx)
nVar= length(xx);
sum = 0;
for ii = 1:(nVar-1)
	xi = xx(ii);
	xnext = xx(ii+1);
	new = 100*(xnext-xi^2)^2 + (xi-1)^2;
	sum = sum + new;
end

o = sum;

end

%dixonprice

function o = dixonprice(xx)
x1 = xx(1);
nVar = length(xx);
term1 = (x1-1)^2;

sum = 0;
for ii = 2:nVar
	xi = xx(ii);
	xold = xx(ii-1);
	new = ii * (2*xi^2 - xold)^2;
	sum = sum + new;
end

o = term1 + sum;

end


%sumsquare

function o = sumsquare(xx)
nVar = length(xx);
sum = 0;
for ii = 1:nVar
	xi = xx(ii);
    sum=sum+ii.*(xi.^2);
end
o=sum;
end


%quartic

function o = quartic(xx)
nVar = length(xx);
sum = 0;
for ii = 1:nVar
	xi = xx(ii);
    sum=sum+ii.*(xi.^4);
end
o=sum+rand;
end


%elliptic

function o = elliptic(xx)
nVar = length(xx);
sum = 0;
for ii = 1:nVar
	xi = xx(ii);
    sum=sum+((10^6).^((ii-1)./(nVar-1))).*(xi.^2);
end
o=sum;
end

%%̶Ժ

%drop_wave
function [y] =drop_wave(xx)
x1 = xx(1);
x2 = xx(2);


frac1 = 1 + cos(12*sqrt(x1^2+x2^2));
frac2 = 0.5*(x1^2+x2^2) + 2;

y = -frac1/frac2;

end


function [y] = schaffer(xx)
x1 = xx(1);
x2 = xx(2);

fact1 = (sin(x1^2-x2^2))^2 - 0.5;
fact2 = (1 + 0.001*(x1^2+x2^2))^2;

y = 0.5 + fact1/fact2;

end

function [y] = cross_in_tray(xx)
x1 = xx(1);
x2 = xx(2);

fact1 = sin(x1)*sin(x2);
fact2 = exp(abs(100 - sqrt(x1^2+x2^2)/pi));

y = -0.0001 * (abs(fact1*fact2)+1)^0.1;

end
